{% load i18n %}
{% load bootstrap %}

<div class="panel panel-default">
    <div class="panel-heading">
        <div class="panel-title">
            {% translate "Modify Topic" %}
        </div>
    </div>

    <div class="panel-body">
        <form id="aa-forum-form-message-modify" autocomplete="off" action="{% url 'aa_forum:forum_topic_modify' topic.board.category.slug topic.board.slug topic.slug %}" method="post">
            {% csrf_token %}

            {{ form|bootstrap }}

            {% include "aa_forum/partials/form/required-field-hint.html" %}

            <div class="form-group text-right clearfix">
                <button class="btn btn-primary btn-sm" type="submit">
                    {% translate "Modify" %}
                </button>
            </div>
        </form>
    </div>
</div>
